==> brmo-stufbg204-1.5.0-sources.jar: nl/egem/stuf/stuf0204/ExtraElementen.java <==

package nl.egem.stuf.stuf0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ExtraElementen complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ExtraElementen">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded">
 *         &lt;element ref="{http://www.egem.nl/StUF/StUF0204}extraElement" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExtraElementen", propOrder = {
    "extraElement"
})
public class ExtraElementen {

    @XmlElement(nillable = true)
    protected List<ExtraElement> extraElement;

    /**
     * Gets the value of the extraElement property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extraElement property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtraElement().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ExtraElement }
     * 
     * 
     */
    public List<ExtraElement> getExtraElement() {
        if (extraElement == null) {
            extraElement = new ArrayList<ExtraElement>();
        }
        return this.extraElement;
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/stuf0204/ExtraElementen.java <==

package nl.egem.stuf.stuf0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ExtraElementen complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ExtraElementen"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence maxOccurs="unbounded"&gt;
 *         &lt;element ref="{http://www.egem.nl/StUF/StUF0204}extraElement" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExtraElementen", propOrder = {
    "extraElement"
})
public class ExtraElementen {

    @XmlElement(nillable = true)
    protected List<ExtraElement> extraElement;

    /**
     * Gets the value of the extraElement property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extraElement property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtraElement().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ExtraElement }
     * 
     * 
     */
    public List<ExtraElement> getExtraElement() {
        if (extraElement == null) {
            extraElement = new ArrayList<ExtraElement>();
        }
        return this.extraElement;
    }

}
